From c19cbe68d5a4a1363b320debfc6b3e93dbb7e8ac Mon Sep 17 00:00:00 2001
From: Timo Tambet <ttambet@gmail.com>
Date: Sun, 26 Feb 2017 00:37:06 +0200
Subject: [PATCH 3/5] Make network panel optional

Signed-off-by: Gilles Dartiguelongue <eva@gentoo.org>
[Updated for 3.23.90]
Signed-off-by: Timo Tambet <ttambet@gmail.com>
---
 configure.ac | 43 +++++++++++++++++++++++++------------------
 1 file changed, 25 insertions(+), 18 deletions(-)

diff --git a/configure.ac b/configure.ac
index b47dbc8..4af24d0 100644
--- a/configure.ac
+++ b/configure.ac
@@ -275,24 +275,31 @@ linux_usb_error_or_warn()
 	esac
 }
 
-PKG_CHECK_MODULES(NETWORK_MANAGER,
-                  libnm >= $NETWORK_MANAGER_REQUIRED_VERSION
-                  libnma >= $NETWORK_MANAGER_APPLET_REQUIRED_VERSION
-                  mm-glib >= $MODEM_MANAGER_REQUIRED_VERSION,
-                  [have_networkmanager=yes], have_networkmanager=no)
-if test "x$have_networkmanager" = xno ; then
-        linux_error_or_warn "*** Network panel will not be built (NetworkManager or ModemManager not found) ***"
-else
-	AC_DEFINE(BUILD_NETWORK, 1, [Define to 1 to build the Network panel])
-fi
-AM_CONDITIONAL(BUILD_NETWORK, [test x$have_networkmanager = xyes])
-if test x${have_networkmanager} = xyes; then
-  AC_DEFINE(HAVE_NETWORK_MANAGER, 1, [Define to 1 if NetworkManager is available])
-  NM_VPN_CONFIG_DIR=`$PKG_CONFIG --variable configdir NetworkManager`/VPN
-  NM_VPN_MODULE_DIR=`$PKG_CONFIG --variable plugindir NetworkManager`
-  AC_SUBST(NM_VPN_CONFIG_DIR)
-  AC_SUBST(NM_VPN_MODULE_DIR)
-fi
+AC_ARG_ENABLE([networkmanager],
+              AS_HELP_STRING([--disable-networkmanager], [Disable network panel]),
+              [],
+              [enable_networkmanager=auto])
+AS_IF([test "$enable_networkmanager" != "no"],
+      [
+        PKG_CHECK_MODULES(NETWORK_MANAGER,
+                          libnm >= $NETWORK_MANAGER_REQUIRED_VERSION
+                          libnma >= $NETWORK_MANAGER_APPLET_REQUIRED_VERSION
+                          mm-glib >= $MODEM_MANAGER_REQUIRED_VERSION,
+                          [have_networkmanager=yes], [have_networkmanager=no])
+
+        AS_IF([test "$have_networkmanager" = "no"],
+              [
+                AC_MSG_WARN([*** Network panel will not be built (NetworkManager or ModemManager not found) ***])
+              ], [
+                AC_DEFINE(BUILD_NETWORK, 1, [Define to 1 to build the Network panel])
+                AC_DEFINE(HAVE_NETWORK_MANAGER, 1, [Define to 1 if NetworkManager is available])
+                NM_VPN_CONFIG_DIR=`$PKG_CONFIG --variable configdir NetworkManager`/VPN
+                NM_VPN_MODULE_DIR=`$PKG_CONFIG --variable plugindir NetworkManager`
+                AC_SUBST([NM_VPN_CONFIG_DIR])
+                AC_SUBST([NM_VPN_MODULE_DIR])
+              ])
+      ])
+AM_CONDITIONAL(BUILD_NETWORK, [test "$have_networkmanager" = "yes"])
 
 # Check for power panel
 if test x${have_networkmanager} = xyes; then
-- 
2.10.2

